@@ -2,15 +2,17 @@ import asyncio
 import random
 
 import pytest
+
 from cashews import Cache
-from cashews.cache_utils.invalidate import invalidate_func
+from cashews.validation import invalidate_func, set_invalidate_further
 
 pytestmark = pytest.mark.asyncio
 
+_cache_ = Cache()
+
 
 @pytest.fixture(name="cache")
 async def _cache():
-    _cache_ = Cache()
     _cache_.setup("mem://")
     return _cache_
 
@@ -60,7 +62,7 @@ async def test_invalidate_decor(cache: Cache):
 
 
 async def test_invalidate_decor_complicate(cache: Cache):
-    @cache(ttl=1, func_args=("arg", "key", "flag", "name"))
+    @cache(ttl=1, key="arg-{arg}:{key}:{flag}:{name}")
     async def func(arg, key=b"test", flag=True, **kwargs):
         return random.random()
 
@@ -101,3 +103,21 @@ async def test_invalidate_decor_complicate(cache: Cache):
     await asyncio.sleep(0)
     assert first_call != await func("test")
     assert not_invalidate == await func("test", flag=False)
+
+
+async def test_invalidate_further(cache):
+    @cache(ttl=10000)
+    async def func():
+        return random.random()
+
+    async def clear():
+        set_invalidate_further()
+        return await func()
+
+    first = await func()
+    assert await func() == first
+
+    assert await asyncio.create_task(clear()) != first  # the key was deleted
+    second = await func()
+    assert second != first
+    assert await func() == second
